<?php
/**
 * @file
 * Easy Social theme functions.
 */

/**
 * Returns HTML for the Easy Social widgets.
 *
 * @ingroup themeable
 */
function theme_easy_social($variables) {
  $widgets = $variables['widgets'];
  $definitions = $variables['definitions'];
  $config = $variables['config'];

  $build = array();

  foreach ($widgets as $widget) {
    if (!array_key_exists($widget, $definitions)) {
      throw new EasySocialException(t('No definition found for the widget: @name', array('@name' => $widget)));
//      watchdog('easy_social', 'No definition found for widget: @widget', array('@widget' => $widget), WATCHDOG_ERROR);
    }

    // Handle css includes.
    $attached = array();

    if (array_key_exists('css', $definitions[$widget])) {
      $attached['css'] = $definitions[$widget]['css'];
    }

    // Determine how to handle js.
    if (array_key_exists('js', $definitions[$widget])) {
      if ($config->get('global.async')) {
        _easy_social_add_js($definitions[$widget]['js']);
      }
      else {
        $attached['js'] = $definitions[$widget]['js'];
      }
    }

    $build[$widget] = array(
      '#theme' => "easy_social_{$widget}",
      // @TODO pass in some kind of context?
      // @TODO #weight ?,
      '#attached' => $attached,
    );
  }

  return drupal_render($build);
}

/**
 * Returns HTML for the Easy Social Twitter widget.
 *
 * @ingroup themeable
 */
function theme_easy_social_twitter($variables) {
  $attributes = array(
    'class' => array('twitter-share-button'),
  );

  if (!empty($variables['via'])) {
    $attributes['data-via'] = $variables['via'];
  }

  if (!empty($variables['related'])) {
    $attributes['data-related'] = $variables['related'];
  }

  if (isset($variables['size'])) {
    $attributes['data-size'] = ($variables['size'] == 1) ? 'large' : 'medium';
  }

  if (!empty($variables['count'])) {
    $attributes['data-count'] = $variables['count'];
  }

  if (!empty($variables['lang'])) {
    $attributes['data-lang'] = $variables['lang'];
  }

  if (!empty($variables['hashtags'])) {
    $attributes['data-hashtags'] = $variables['hashtags'];
  }

  if (isset($variables['dnt']) && $variables['dnt'] == 1) {
    $attributes['data-dnt'] = 'true';
  }

  $build = array(
    '#theme' => 'link',
    '#text' => t('Share on Twitter'),
    '#path' => 'https://twitter.com/share',
    '#options' => array(
      'attributes' => $attributes,
      'html' => FALSE,
    ),
    '#prefix' => "\n" . '<span class="easy-social twitter">',
    '#suffix' => '</span>',
  );

  return drupal_render($build);
}

/**
 * Returns HTML for the Easy Social Facebook widget.
 *
 * @ingroup themeable
 */
function theme_easy_social_facebook($variables) {
  $doc = new \DOMDocument();

  // Wrapper element.
  $wrapper = $doc->createElement('div', '');
  $attribute = $doc->createAttribute('class');
  $attribute->value = 'fb-like';
  $wrapper->appendChild($attribute);

  // Href.
  $attribute = $doc->createAttribute('data-href');
  $attribute->value = $variables['url'];
  $wrapper->appendChild($attribute);

  // Send.
  $attribute = $doc->createAttribute('data-send');
  $attribute->value = $variables['send'];
  $wrapper->appendChild($attribute);

  // Width.
  $attribute = $doc->createAttribute('data-width');
  $attribute->value = $variables['width'];
  $wrapper->appendChild($attribute);

  // Show faces.
  $attribute = $doc->createAttribute('data-show-faces');
  $attribute->value = $variables['show_faces'];
  $wrapper->appendChild($attribute);

  // Layout.
  if ($variables['layout'] !== 'standard') {
    $attribute = $doc->createAttribute('data-layout');
    $attribute->value = $variables['layout'];
    $wrapper->appendChild($attribute);
  }

  // Font.
  if (!empty($variables['font'])) {
    $attribute = $doc->createAttribute('data-font');
    $attribute->value = $variables['font'];
    $wrapper->appendChild($attribute);
  }

  // Color scheme.
  if ($variables['colorscheme'] !== 'light') {
    $attribute = $doc->createAttribute('data-colorscheme');
    $attribute->value = $variables['colorscheme'];
    $wrapper->appendChild($attribute);
  }

  // Action.
  if ($variables['action'] !== 'like') {
    $attribute = $doc->createAttribute('data-action');
    $attribute->value = $variables['action'];
    $wrapper->appendChild($attribute);
  }

  // Done.
  $doc->appendChild($wrapper);

  $build = array(
    '#markup' => $doc->saveXML($wrapper),
    '#prefix' => "\n" . '<span class="easy-social facebook">',
    '#suffix' => '</span>',
  );

  return drupal_render($build);
}

/**
 * Returns HTML for the Easy Social Google+ widget.
 *
 * @ingroup themeable
 */
function theme_easy_social_googleplus($variables) {
  $doc = new \DOMDocument();

  // Wrapper element.
  $wrapper = $doc->createElement('div', '');
  $attribute = $doc->createAttribute('class');
  $attribute->value = 'g-plusone';
  $wrapper->appendChild($attribute);

  // Size.
  if ($variables['size'] !== 'large') {
    $attribute = $doc->createAttribute('data-size');
    $attribute->value = $variables['size'];
    $wrapper->appendChild($attribute);
  }

  // Annotation.
  if ($variables['annotation'] !== 'bubble') {
    $attribute = $doc->createAttribute('data-annotation');
    $attribute->value = $variables['annotation'];
    $wrapper->appendChild($attribute);
  }

  // Width.
  $attribute = $doc->createAttribute('data-width');
  $attribute->value = $variables['width'];
  $wrapper->appendChild($attribute);

  // Callback.
  if (!empty($variables['callback'])) {
    $attribute = $doc->createAttribute('data-callback');
    $attribute->value = $variables['callback'];
    $wrapper->appendChild($attribute);
  }

  // Href.
  $attribute = $doc->createAttribute('data-href');
  $attribute->value = $variables['url'];
  $wrapper->appendChild($attribute);

  // Done.
  $doc->appendChild($wrapper);

  $build = array(
    '#markup' => $doc->saveXML($wrapper),
    '#prefix' => "\n" . '<span class="easy-social googleplus">',
    '#suffix' => '</span>',
  );

  return drupal_render($build);
}

/**
 * Returns HTML for the Easy Social LinkedIn widget.
 *
 * @ingroup themeable
 */
function theme_easy_social_linkedin($variables) {
  $doc = new \DOMDocument();

  // Wrapper element.
  // @TODO test whether we can put lang here.
  $wrapper = $doc->createElement('script', '');
  $attribute = $doc->createAttribute('type');
  $attribute->value = 'IN/Share';
  $wrapper->appendChild($attribute);

  // Counter.
  if ($variables['counter'] !== 'none') {
    $attribute = $doc->createAttribute('data-counter');
    $attribute->value = $variables['counter'];
    $wrapper->appendChild($attribute);
  }

  // Url.
  $attribute = $doc->createAttribute('data-url');
  $attribute->value = $variables['url'];
  $wrapper->appendChild($attribute);

  // Done.
  $doc->appendChild($wrapper);

  $build = array(
    '#markup' => $doc->saveXML($wrapper),
    '#prefix' => "\n" . '<span class="easy-social linkedin">',
    '#suffix' => '</span>',
  );

  return drupal_render($build);
}

/**
 * Returns HTML for the Easy Social Pinterest widget.
 *
 * @ingroup themeable
 */
function theme_easy_social_pinterest($variables) {
  $attributes = array(
    'class' => array('pinterest-share'),
    'data-pin-do' => 'buttonPin',
  );

  $attributes['data-pin-config'] = $variables['config'];

  $build = array(
    '#theme' => 'link',
    '#text' => '<img src="//assets.pinterest.com/images/pidgets/pin_it_button.png" />',
    '#path' => '/pinterest.com/pin/create/button',
    '#options' => array(
      'attributes' => $attributes,
      'html' => TRUE,
      'query' => array(
        'url' => $variables['url'],
        'media' => $variables['image'],
        'description' => $variables['description'],
      ),
    ),
    '#prefix' => "\n" . '<span class="easy-social pinterest">',
    '#suffix' => '</span>',
  );

  return drupal_render($build);
}
