<?php

/**
 * @file
 * Contains \Drupal\easy_social\EasySocialSettingsForm.
 */

namespace Drupal\easy_social;

use Drupal\system\SystemConfigFormBase;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Config\Context\ContextInterface;
use Drupal\Core\Extension\ModuleHandler;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure user settings for this site.
 */
class EasySocialSettingsForm extends SystemConfigFormBase {
  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandler
   */
  protected $moduleHandler;

  /**
   * Constructs a \Drupal\user\AccountSettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\Context\ContextInterface $context
   *   The configuration context.
   * @param \Drupal\Core\Extension\ModuleHandler $module_handler
   *   The module handler.
   */
  public function __construct(ConfigFactory $config_factory, ContextInterface $context, ModuleHandler $module_handler) {
    parent::__construct($config_factory, $context);
    $this->moduleHandler = $module_handler;
  }

  /**
   * Implements \Drupal\Core\ControllerInterface::create().
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.context.free'),
      $container->get('module_handler')
    );
  }

  /**
   * Implements \Drupal\Core\Form\FormInterface::getFormID().
   */
  public function getFormID() {
    return 'easy_social_settings';
  }

  /**
   * Implements \Drupal\Core\Form\FormInterface::buildForm().
   */
  public function buildForm(array $form, array &$form_state) {
    $config = $this->configFactory->get('easy_social.settings');

    if ($widgets = easy_social_get_widgets()) {
      $widget_options = array();

      foreach ($widgets as $machine_name => $widget) {
        $widget_options[$machine_name] = $widget['name'];
      }

      $form['widgets'] = array(
        '#type' => 'checkboxes',
        '#title' => t('Enabled widgets'),
        // @TODO decide whether we're going to enable overrides for specific entities and, if so, update the description.
        '#description' => t('Select the social sharing widgets you would like to enable globally. This setting can be overriden per block and entity type.'),
        '#default_value' => (array) $config->get('global.widgets'),
        '#options' => $widget_options,
      );

      $form['advanced'] = array(
        '#type' => 'fieldset',
        '#title' => t('Advanced settings'),
        '#collapsible' => TRUE,
        '#collapsed' => TRUE,
      );

      $form['advanced']['async'] = array(
        '#type' => 'checkbox',
        '#title' => t('Load javascript asynchronously'),
        '#description' => t('This is recommended for performance purposes.'),
        '#default_value' => $config->get('global.async'),
      );
    }
    else {
      $form['widgets_empty'] = array(
        '#prefix' => '<div class="empty">',
        '#suffix' => '</div>',
        '#markup' => t('There are no widgets defined.'),
      );
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * Implements \Drupal\Core\Form\FormInterface::submitForm().
   */
  public function submitForm(array &$form, array &$form_state) {
    parent::submitForm($form, $form_state);

    $this->configFactory->get('easy_social.settings')
      ->set('global.widgets', $form_state['values']['widgets'])
      ->set('global.async', $form_state['values']['async'])
      ->save();
  }

}
